@@ -238,7 +238,7 @@
                      <?php
 
     if($properties['variations_tools'] == '1') {
-        echo '<a class="menu_item" href="variation-info_form.cgi" >Variation info <img src="images/onebit_49.png" height="30" class="new"></img></a>
+        echo '<!-- <a class="menu_item" href="variation-info_form.cgi" >Variation info <img src="images/onebit_49.png" height="30" class="new"></img></a> -->
                          <a class="menu_item" href="retrieve-variation-seq_form.cgi" >Retrieve variation sequences <img src="images/onebit_49.png" height="30" class="new"></img></a>
                          <a class="menu_item" href="variation-scan_form.cgi" >Scan variations with motifs <img src="images/onebit_49.png" height="30" class="new"></img></a>
                          '; }
@@ -312,7 +312,7 @@
 
                          <a class="menu_item" href="publications.cgi" >Publications</a>
                          <a class="menu_item" href="credits.php" >Credits</a>
-                         <a class="menu_item" href="http://teaching.rsat.eu/download-request_form.cgi" >Download</a>
+                         <a class="menu_item" href="https://github.com/rsa-tools/" >Download</a>
                          <a class="menu_item_last" href="htmllink.cgi?title=RSAT-motif&file=motif_databases/" >Motif databases</a>
                          <a class="menu_item_last" href="htmllink.cgi?title=RSAT-Data&file=data/" >Data</a>
 
